@@ -1,20 +1,24 @@
 ﻿/*
- * FCKeditor - The text editor for internet
- * Copyright (C) 2003-2006 Frederico Caldeira Knabben
- * 
- * Licensed under the terms of the GNU Lesser General Public License:
- * 		http://www.opensource.org/licenses/lgpl-license.php
- * 
- * For further information visit:
- * 		http://www.fckeditor.net/
- * 
- * "Support Open Source software. What about a donation today?"
- * 
- * File Name: gl.js
- * 	Galician language file.
- * 
- * File Authors:
- * 		Fernando Riveiro Lopez
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2007 Frederico Caldeira Knabben
+ *
+ * == BEGIN LICENSE ==
+ *
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ *
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ *
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ *
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ *
+ * == END LICENSE ==
+ *
+ * Galician language file.
  */
 
 var FCKLang =
@@ -72,7 +76,7 @@ NumberedListLbl		: "Lista Numerada",
 NumberedList		: "Inserir/Eliminar Lista Numerada",
 BulletedListLbl		: "Marcas",
 BulletedList		: "Inserir/Eliminar Marcas",
-ShowTableBorders	: "Mostrar Bordes das Taboas",
+ShowTableBorders	: "Mostrar Bordes das Táboas",
 ShowDetails			: "Mostrar Marcas Parágrafo",
 Style				: "Estilo",
 FontFormat			: "Formato",
@@ -113,9 +117,9 @@ InsertCell			: "Inserir Cela",
 DeleteCells			: "Borrar Cela",
 MergeCells			: "Unir Celas",
 SplitCell			: "Partir Celas",
-TableDelete			: "Borrar Taboa",
+TableDelete			: "Borrar Táboa",
 CellProperties		: "Propriedades da Cela",
-TableProperties		: "Propriedades da Taboa",
+TableProperties		: "Propriedades da Táboa",
 ImageProperties		: "Propriedades Imaxe",
 FlashProperties		: "Propriedades Flash",
 
@@ -130,7 +134,7 @@ SelectionFieldProp	: "Propriedades do Campo de Selección",
 TextareaProp		: "Propriedades da Área de Texto",
 FormProp			: "Propriedades do Formulario",
 
-FontFormats			: "Normal;Formateado;Enderezo;Enacabezado 1;Encabezado 2;Encabezado 3;Encabezado 4;Encabezado 5;Encabezado 6;Paragraph (DIV)",
+FontFormats			: "Normal;Formateado;Enderezo;Enacabezado 1;Encabezado 2;Encabezado 3;Encabezado 4;Encabezado 5;Encabezado 6;Paragraph (DIV)",		//REVIEW : Check _getfontformat.html
 
 // Alerts and Messages
 ProcessingXHTML		: "Procesando XHTML. Por facor, agarde...",
@@ -225,7 +229,7 @@ DlgLnkURL			: "URL",
 DlgLnkAnchorSel		: "Seleccionar unha Referencia",
 DlgLnkAnchorByName	: "Por Nome de Referencia",
 DlgLnkAnchorById	: "Por Element Id",
-DlgLnkNoAnchors		: "<Non hai referencias disponibles no documento>",
+DlgLnkNoAnchors		: "<Non hai referencias disponibles no documento>",		//REVIEW : Change < and > with ( and )
 DlgLnkEMail			: "Enderezo de E-Mail",
 DlgLnkEMailSubject	: "Asunto do Mensaxe",
 DlgLnkEMailBody		: "Corpo do Mensaxe",
@@ -258,6 +262,7 @@ DlgLnkPopTop		: "Posición dende Arriba",
 DlnLnkMsgNoUrl		: "Por favor, escriba a ligazón URL",
 DlnLnkMsgNoEMail	: "Por favor, escriba o enderezo de e-mail",
 DlnLnkMsgNoAnchor	: "Por favor, seleccione un destino",
+DlnLnkMsgInvPopName	: "The popup name must begin with an alphabetic character and must not contain spaces",	//MISSING
 
 // Color Dialog
 DlgColorTitle		: "Seleccionar Color",
@@ -272,7 +277,7 @@ DlgSmileyTitle		: "Inserte un Smiley",
 DlgSpecialCharTitle	: "Seleccione Caracter Especial",
 
 // Table Dialog
-DlgTableTitle		: "Propiedades da Taboa",
+DlgTableTitle		: "Propiedades da Táboa",
 DlgTableRows		: "Filas",
 DlgTableColumns		: "Columnas",
 DlgTableBorder		: "Tamaño do Borde",
@@ -332,7 +337,6 @@ DlgReplaceReplAllBtn	: "Substitiur Todo",
 DlgReplaceWordChk		: "Coincidir con toda a palabra",
 
 // Paste Operations / Dialog
-PasteErrorPaste	: "Os axustes de seguridade do seu navegador non permiten que o editor realice automáticamente as tarefas de pegado. Por favor, use o teclado para iso (Ctrl+V).",
 PasteErrorCut	: "Os axustes de seguridade do seu navegador non permiten que o editor realice automáticamente as tarefas de corte. Por favor, use o teclado para iso (Ctrl+X).",
 PasteErrorCopy	: "Os axustes de seguridade do seu navegador non permiten que o editor realice automáticamente as tarefas de copia. Por favor, use o teclado para iso (Ctrl+C).",
 
@@ -340,6 +344,7 @@ PasteAsText		: "Pegar como texto plano",
 PasteFromWord	: "Pegar dende Word",
 
 DlgPasteMsg2	: "Por favor, pegue dentro do seguinte cadro usando o teclado (<STRONG>Ctrl+V</STRONG>) e pulse <STRONG>OK</STRONG>.",
+DlgPasteSec		: "Because of your browser security settings, the editor is not able to access your clipboard data directly. You are required to paste it again in this window.",	//MISSING
 DlgPasteIgnoreFont		: "Ignorar as definicións de Tipografía",
 DlgPasteRemoveStyles	: "Eliminar as definicións de Estilos",
 DlgPasteCleanBox		: "Limpar o Cadro",
@@ -374,8 +379,11 @@ DlgSpellManyChanges		: "Corrección ortográfica rematada: %1 verbas substituida
 IeSpellDownload			: "O corrector ortográfico non está instalado. ¿Quere descargalo agora?",
 
 // Button Dialog
-DlgButtonText	: "Texto (Valor)",
-DlgButtonType	: "Tipo",
+DlgButtonText		: "Texto (Valor)",
+DlgButtonType		: "Tipo",
+DlgButtonTypeBtn	: "Button",	//MISSING
+DlgButtonTypeSbm	: "Submit",	//MISSING
+DlgButtonTypeRst	: "Reset",	//MISSING
 
 // Checkbox and Radio Button Dialogs
 DlgCheckboxName		: "Nome",
@@ -424,6 +432,7 @@ DlgHiddenValue	: "Valor",
 // Bulleted List Dialog
 BulletedListProp	: "Propriedades das Marcas",
 NumberedListProp	: "Propriedades da Lista de Numeración",
+DlgLstStart			: "Start",	//MISSING
 DlgLstType			: "Tipo",
 DlgLstTypeCircle	: "Círculo",
 DlgLstTypeDisc		: "Disco",
@@ -446,6 +455,15 @@ DlgDocLangDirLTR	: "Esquerda a Dereita (LTR)",
 DlgDocLangDirRTL	: "Dereita a Esquerda (RTL)",
 DlgDocLangCode		: "Código de Idioma",
 DlgDocCharSet		: "Codificación do Xogo de Caracteres",
+DlgDocCharSetCE		: "Central European",	//MISSING
+DlgDocCharSetCT		: "Chinese Traditional (Big5)",	//MISSING
+DlgDocCharSetCR		: "Cyrillic",	//MISSING
+DlgDocCharSetGR		: "Greek",	//MISSING
+DlgDocCharSetJP		: "Japanese",	//MISSING
+DlgDocCharSetKR		: "Korean",	//MISSING
+DlgDocCharSetTR		: "Turkish",	//MISSING
+DlgDocCharSetUN		: "Unicode (UTF-8)",	//MISSING
+DlgDocCharSetWE		: "Western European",	//MISSING
 DlgDocCharSetOther	: "Outra Codificación do Xogo de Caracteres",
 
 DlgDocDocType		: "Encabezado do Tipo de Documento",
@@ -475,12 +493,12 @@ DlgTemplatesTitle	: "Plantillas de Contido",
 DlgTemplatesSelMsg	: "Por favor, seleccione a plantilla a abrir no editor<br>(o contido actual perderase):",
 DlgTemplatesLoading	: "Cargando listado de plantillas. Por favor, espere...",
 DlgTemplatesNoTpl	: "(Non hai plantillas definidas)",
+DlgTemplatesReplace	: "Replace actual contents",	//MISSING
 
 // About Dialog
 DlgAboutAboutTab	: "Acerca de",
 DlgAboutBrowserInfoTab	: "Información do Navegador",
 DlgAboutLicenseTab	: "Licencia",
 DlgAboutVersion		: "versión",
-DlgAboutLicense		: "Licencia concedida baixo os termos da GNU Lesser General Public License",
 DlgAboutInfo		: "Para máis información visitar:"
-}
\ No newline at end of file
+};
\ No newline at end of file
